@@ -56,7 +56,7 @@ async def main():
                 database=DbConfig(
                     host="localhost",
                     port="5432",
-                    database="aedb",
+                    database="testesmdb",
                     user="testuser",
                     password="Fedora132",
                     db_schema="ae",
@@ -64,7 +64,7 @@ async def main():
                     migrations_path=Path("")
                 )))
     # router = YamlRouter(Path("../applyed_files/config/routing.yaml"), chain)
-    router = DictRouter(routes_dict, chain)
+    router = DictRouter(routes_dict, chain, versioning=False)
     workers = create_io_workers(container.app_config.server(), router, workers_num=2)
     subscribe_worker_rt_callback(*workers, event_type=AeEvent, callback=resolve_send_event, use_nested_classes=True)
 
