@@ -92,6 +92,7 @@ class DictRouter(ExtRouter):
                     methods_confs = []
                     endpoint_handler = params.pop("handler", None)
                     endpoint_protector = params.pop("protector", None)
+                    endpoint_response_fabric = params.pop("response_fabric", None)
                     for method_name, method_params in params.items():
                         target_func = method_params.get('handler')
                         target_func = target_func if target_func else endpoint_handler
@@ -99,9 +100,17 @@ class DictRouter(ExtRouter):
                         protector = protector if protector else endpoint_protector
                         in_dto = method_params.get("in_dto")
                         out_dto = method_params.get("out_dto")
-                        chain = self.chaining(
-                            protector=protector,
-                            in_struct=in_dto)(target_func)
+                        response_fabric = method_params.get("response_fabric")
+                        response_fabric = response_fabric if response_fabric else endpoint_response_fabric
+                        if response_fabric:
+                            chain = self.chaining(
+                                protector=protector,
+                                in_struct=in_dto,
+                                response_fabric=response_fabric)(target_func)
+                        else:
+                            chain = self.chaining(
+                                protector=protector,
+                                in_struct=in_dto)(target_func)
                         methods_confs.append(RouteMethodConf(method_name=method_name,
                                                              protector=protector,
                                                              in_dto=in_dto,
